@@ -28,55 +28,54 @@ from __future__ import annotations
 
 import typing
 from typing import Any
-from typing import NamedTuple
-from typing import Optional
 from typing import cast
+from typing import Optional
 
 import gc
-import os
-import sys
 import logging
-import weakref
+import os
 import pprint
+import sys
+import weakref
 from collections import defaultdict
 
-import nbxmpp
-from nbxmpp.idlequeue import IdleQueue
 from gi.repository import Gdk
 from gi.repository import GLib
 from gi.repository import GObject
+from nbxmpp.idlequeue import IdleQueue
 
 import gajim
-from gajim.common import types
 from gajim.common import config as c_config
 from gajim.common import configpaths
 from gajim.common import ged as ged_module
-from gajim.common.i18n import LANG
+from gajim.common import types
 from gajim.common.const import Display
+from gajim.common.i18n import LANG
 
 if typing.TYPE_CHECKING:
-    from gajim.gui.main import MainWindow
-    from gajim.gui.application import GajimApplication
-    from gajim.common.storage.cache import CacheStorage
-    from gajim.common.storage.archive import MessageArchiveStorage
-    from gajim.common.cert_store import CertificateStore
     from gajim.common.call_manager import CallManager
+    from gajim.common.cert_store import CertificateStore
+    from gajim.common.commands import ChatCommands  # noqa: F401
     from gajim.common.preview import PreviewManager
+    from gajim.common.storage.archive import MessageArchiveStorage
+    from gajim.common.storage.cache import CacheStorage
+    from gajim.common.storage.draft import DraftStorage
+    from gajim.common.storage.events import EventStorage
     from gajim.common.task_manager import TaskManager
+    from gajim.gui.application import GajimApplication  # noqa: F401
+    from gajim.gui.main import MainWindow  # noqa: F401
 
 
 interface = cast(types.InterfaceT, None)
-# Interface to run a thread and then a callback
-thread_interface = None
 config = c_config.Config()
 settings = cast(types.SettingsT, None)
 version = gajim.__version__
 connections: dict[str, types.Client] = {}
 avatar_cache: dict[str, dict[str, Any]] = {}
 bob_cache: dict[str, bytes] = {}
-ipython_window = None
 app = None  # type: GajimApplication
 window = None  # type: MainWindow
+commands = None  # type: ChatCommands
 
 ged = ged_module.GlobalEventsDispatcher()  # Global Events Dispatcher
 plugin_manager = cast(types.PluginManagerT, None)  # Plugins Manager
@@ -87,6 +86,8 @@ class Storage:
     def __init__(self):
         self.cache: CacheStorage = None
         self.archive: MessageArchiveStorage = None
+        self.events: EventStorage = None
+        self.drafts: DraftStorage = None
 
 
 storage = Storage()
@@ -95,11 +96,6 @@ css_config = cast(types.CSSConfigT, None)
 
 transport_type: dict[str, str] = {}
 
-# dict of rooms that must be automatically configured
-# and for which we have a list of invities
-# {account: {room_jid: {'invities': []}}}
-automatic_rooms: dict[str, dict[str, dict[str, list[str]]]] = {}
-
 # list of contacts that has just signed out
 to_be_removed: dict[str, list[str]] = {}
 
@@ -143,12 +139,6 @@ _dependencies = {
 _tasks: dict[int, list[Any]] = defaultdict(list)
 
 
-class RecentGroupchat(NamedTuple):
-    room: str
-    server: str
-    nickname: str
-
-
 def print_version() -> None:
     log('gajim').info('Gajim Version: %s', gajim.__version__)
 
@@ -230,14 +220,17 @@ def detect_dependencies() -> None:
         pass
 
     # UPNP
-    try:
-        gi.require_version('GUPnPIgd', '1.0')
-        from gi.repository import GUPnPIgd
-        global gupnp_igd  # pylint: disable=global-statement
-        gupnp_igd = GUPnPIgd.SimpleIgd()
-        _dependencies['UPNP'] = True
-    except ValueError:
-        pass
+    # GUPnPidg uses libsoup3 which is incompatible with Gajim.
+    # Don’t load until Gajim is ported to libsoup3
+    #
+    # try:
+    #     gi.require_version('GUPnPIgd', '1.0')
+    #     from gi.repository import GUPnPIgd
+    #     global gupnp_igd  # pylint: disable=global-statement
+    #     gupnp_igd = GUPnPIgd.SimpleIgd()
+    #     _dependencies['UPNP'] = True
+    # except ValueError:
+    #     pass
 
     # IDLE
     try:
@@ -338,19 +331,12 @@ def get_jid_without_resource(jid: str) -> str:
     return jid.split('/')[0]
 
 
-def get_number_of_accounts() -> int:
-    """
-    Return the number of ALL accounts
-    """
-    return len(connections.keys())
-
-
 def get_number_of_connected_accounts(
         accounts_list: Optional[list[str]] = None) -> int:
-    """
+    '''
     Returns the number of connected accounts. You can optionally pass an
     accounts_list and if you do those will be checked, else all will be checked
-    """
+    '''
     connected_accounts = 0
     if accounts_list is None:
         accounts = connections.keys()
@@ -371,9 +357,9 @@ def get_available_clients() -> list[types.Client]:
 
 
 def get_connected_accounts(exclude_local: bool = False) -> list[str]:
-    """
+    '''
     Returns a list of CONNECTED accounts
-    """
+    '''
     account_list: list[str] = []
     for account in connections:
         if account == 'Local' and exclude_local:
@@ -395,10 +381,10 @@ def get_accounts_sorted() -> list[str]:
 def get_enabled_accounts_with_labels(
         connected_only: bool = False,
         private_storage_only: bool = False) -> list[list[str]]:
-    """
+    '''
     Returns a list with [account, account_label] entries.
     Order by account_label
-    """
+    '''
     accounts: list[list[str]] = []
     for acc in connections:
         if connected_only and not account_is_connected(acc):
@@ -435,19 +421,15 @@ def account_is_available(account: str) -> bool:
     return connections[account].state.is_available
 
 
-def account_is_disconnected(account: str) -> bool:
-    return not account_is_connected(account)
-
-
 def get_transport_name_from_jid(
         jid: str,
         use_config_setting: bool = True) -> Optional[str]:
 
-    """
+    '''
     Returns 'gg', 'irc' etc
 
     If JID is not from transport returns None.
-    """
+    '''
     # TODO: Rewrite/remove
 
     # FIXME: jid can be None! one TB I saw had this problem:
@@ -485,25 +467,18 @@ def jid_is_transport(jid: str) -> bool:
 
 
 def get_jid_from_account(account_name: str) -> str:
-    """
+    '''
     Return the jid we use in the given account
-    """
+    '''
     name = settings.get_account_setting(account_name, 'name')
     hostname = settings.get_account_setting(account_name, 'hostname')
-    jid = name + '@' + hostname
-    return jid
-
-
-def get_account_from_jid(jid: str) -> Optional[str]:
-    for account in settings.get_accounts():
-        if jid == get_jid_from_account(account):
-            return account
+    return name + '@' + hostname
 
 
 def get_hostname_from_account(account_name: str, use_srv: bool = False) -> str:
-    """
+    '''
     Returns hostname (if custom hostname is used, that is returned)
-    """
+    '''
     if use_srv and connections[account_name].connected_hostname:
         return connections[account_name].connected_hostname
     if settings.get_account_setting(account_name, 'use_custom_host'):
@@ -511,47 +486,10 @@ def get_hostname_from_account(account_name: str, use_srv: bool = False) -> str:
     return settings.get_account_setting(account_name, 'hostname')
 
 
-def get_notification_image_prefix(jid: str) -> str:
-    """
-    Returns the prefix for the notification images
-    """
-    transport_name = get_transport_name_from_jid(jid)
-    if transport_name in ['icq', 'facebook']:
-        prefix = transport_name
-    else:
-        prefix = 'jabber'
-    return prefix
-
-
-def get_recent_groupchats(account: str) -> list[RecentGroupchat]:
-    recent_groupchats = settings.get_account_setting(
-        account, 'recent_groupchats').split()
-
-    recent_list: list[RecentGroupchat] = []
-    for groupchat in recent_groupchats:
-        jid = nbxmpp.JID.from_string(groupchat)
-        recent = RecentGroupchat(jid.localpart, jid.domain, jid.resource)
-        recent_list.append(recent)
-    return recent_list
-
-
-def add_recent_groupchat(account: str, room_jid: str, nickname: str) -> None:
-    recent = settings.get_account_setting(
-        account, 'recent_groupchats').split()
-    full_jid = room_jid + '/' + nickname
-    if full_jid in recent:
-        recent.remove(full_jid)
-    recent.insert(0, full_jid)
-    if len(recent) > 10:
-        recent = recent[0:9]
-    config_value = ' '.join(recent)
-    settings.set_account_setting(account, 'recent_groupchats', config_value)
-
-
 def get_priority(account: str, show: str) -> int:
-    """
+    '''
     Return the priority an account must have
-    """
+    '''
     if not show:
         show = 'online'
 
@@ -561,10 +499,13 @@ def get_priority(account: str, show: str) -> int:
         prio = settings.get_account_setting(account, 'autopriority_' + show)
     else:
         prio = settings.get_account_setting(account, 'priority')
+
     if prio < -128:
-        prio = -128
-    elif prio > 127:
-        prio = 127
+        return -128
+
+    if prio > 127:
+        return 127
+
     return prio
 
 
@@ -574,14 +515,6 @@ def log(domain: str) -> logging.Logger:
     return logging.getLogger(domain)
 
 
-def prefers_app_menu() -> bool:
-    if sys.platform == 'darwin':
-        return True
-    if sys.platform == 'win32':
-        return False
-    return app.prefers_app_menu()
-
-
 def load_css_config() -> None:
     global css_config   # pylint: disable=global-statement
     from gajim.gui.css_config import CSSConfig
