@@ -22,18 +22,18 @@
 # along with Gajim. If not, see <http://www.gnu.org/licenses/>.
 
 from typing import Any
-from typing import Literal
 from typing import Iterator
 from typing import KeysView
+from typing import Literal
 from typing import NamedTuple
 from typing import Optional
 
-import time
-import datetime
 import calendar
+import datetime
 import json
 import logging
 import sqlite3 as sqlite
+import time
 from collections import namedtuple
 
 from nbxmpp import JID
@@ -42,12 +42,11 @@ from nbxmpp.structs import MessageProperties
 
 from gajim.common import app
 from gajim.common import configpaths
-from gajim.common.helpers import AdditionalDataDict
-from gajim.common.const import MAX_MESSAGE_CORRECTION_DELAY
-from gajim.common.const import KindConstant
 from gajim.common.const import JIDConstant
+from gajim.common.const import KindConstant
+from gajim.common.const import MAX_MESSAGE_CORRECTION_DELAY
+from gajim.common.helpers import AdditionalDataDict
 from gajim.common.modules.contacts import GroupchatContact
-
 from gajim.common.storage.base import SqliteStorage
 from gajim.common.storage.base import timeit
 
@@ -191,7 +190,7 @@ class MessageArchiveStorage(SqliteStorage):
 
         assert cursor.description is not None
         fields = [col[0] for col in cursor.description]
-        Row = namedtuple('Row', fields)  # type: ignore
+        Row = namedtuple('Row', fields)  # pyright: ignore
         named_row = Row(*row)
         if 'additional_data' in fields:
             _dict = json.loads(named_row.additional_data or '{}')
@@ -1368,8 +1367,7 @@ class MessageArchiveStorage(SqliteStorage):
             results = cursor.fetchmany(10)
             if not results:
                 break
-            for result in results:
-                yield result
+            yield from results
 
     def remove_history(self, account: str, jid: JID) -> None:
         '''
