@@ -15,22 +15,24 @@
 # You should have received a copy of the GNU General Public License
 # along with Gajim. If not, see <http://www.gnu.org/licenses/>.
 
-from types import FrameType
 from typing import Optional
 
 import os
-import sys
+import platform
 import signal
 import sqlite3
-import platform
-from ctypes import CDLL, byref, create_string_buffer
+import sys
+from ctypes import byref
+from ctypes import CDLL
+from ctypes import create_string_buffer
 from ctypes.util import find_library
+from types import FrameType
+
 from packaging.version import Version as V
 
 import gajim.gui
 
-
-_MIN_NBXMPP_VER = '3.2.5'
+_MIN_NBXMPP_VER = '4.0.0'
 _MIN_GTK_VER = '3.24.30'
 _MIN_CAIRO_VER = '1.16.0'
 _MIN_PYGOBJECT_VER = '3.42.0'
@@ -65,8 +67,7 @@ def _check_required_deps() -> None:
                              'GtkSource': '4',
                              'GObject': '2.0',
                              'Pango': '1.0',
-                             'PangoCairo': '1.0',
-                             'Soup': '2.4'})
+                             'PangoCairo': '1.0'})
     except ValueError as error:
         sys.exit('Missing dependency: %s' % error)
 
