@@ -37,22 +37,22 @@ from __future__ import annotations
 
 from typing import Any
 from typing import Callable
-from typing import Optional
 from typing import cast
+from typing import Optional
 
 import os
 import sys
 from urllib.parse import unquote
 
-from nbxmpp.namespaces import Namespace
-from nbxmpp import JID
-from nbxmpp.protocol import InvalidJid
-from nbxmpp.const import ConnectionType
-from nbxmpp.const import ConnectionProtocol
+from gi.repository import Gdk
 from gi.repository import Gio
 from gi.repository import GLib
 from gi.repository import Gtk
-from gi.repository import Gdk
+from nbxmpp import JID
+from nbxmpp.const import ConnectionProtocol
+from nbxmpp.const import ConnectionType
+from nbxmpp.namespaces import Namespace
+from nbxmpp.protocol import InvalidJid
 
 import gajim
 from gajim.common import app
@@ -62,13 +62,12 @@ from gajim.common import ged
 from gajim.common import idle
 from gajim.common.application import CoreApplication
 from gajim.common.const import GAJIM_FAQ_URI
-from gajim.common.const import GAJIM_WIKI_URI
 from gajim.common.const import GAJIM_SUPPORT_JID
+from gajim.common.const import GAJIM_WIKI_URI
 from gajim.common.exceptions import GajimGeneralException
 from gajim.common.helpers import load_json
 from gajim.common.helpers import open_uri
 from gajim.common.i18n import _
-
 from gajim.gui import menus
 from gajim.gui import structs
 from gajim.gui.about import AboutDialog
@@ -80,8 +79,8 @@ from gajim.gui.const import ALWAYS_ACCOUNT_ACTIONS
 from gajim.gui.const import APP_ACTIONS
 from gajim.gui.const import FEATURE_ACCOUNT_ACTIONS
 from gajim.gui.const import ONLINE_ACCOUNT_ACTIONS
-from gajim.gui.dialogs import DialogButton
 from gajim.gui.dialogs import ConfirmationDialog
+from gajim.gui.dialogs import DialogButton
 from gajim.gui.dialogs import ShortcutsWindow
 from gajim.gui.discovery import ServiceDiscoveryWindow
 from gajim.gui.start_chat import StartChatDialog
@@ -90,7 +89,6 @@ from gajim.gui.util import get_app_windows
 from gajim.gui.util import load_user_iconsets
 from gajim.gui.util import open_window
 
-
 ActionListT = list[tuple[str,
                          Callable[[Gio.SimpleAction, GLib.Variant], Any]]]
 
@@ -220,8 +218,8 @@ class GajimApplication(Gtk.Application, CoreApplication):
         return [option]
 
     def _startup(self) -> None:
-        if sys.platform == 'win32':
-            # Changing the PANGOCAIRO_BACKEND is necessary on Windows
+        if sys.platform in ('win32', 'darwin'):
+            # Changing the PANGOCAIRO_BACKEND is necessary on Windows/MacOS
             # to render colored emoji glyphs
             os.environ['PANGOCAIRO_BACKEND'] = 'fontconfig'
 
@@ -302,7 +300,7 @@ class GajimApplication(Gtk.Application, CoreApplication):
             if cmd == 'join':
                 if len(accounts) == 1:
                     self.activate_action(
-                        'groupchat-join',
+                        'open-chat',
                         GLib.Variant('as', [accounts[0], jid]))
                 else:
                     self.activate_action(
@@ -415,11 +413,10 @@ class GajimApplication(Gtk.Application, CoreApplication):
             ('add-contact', self._on_add_contact_action),
             ('copy-text', self._on_copy_text_action),
             ('open-link', self._on_open_link_action),
-            ('open-mail', self._on_open_mail_action),
             ('remove-history', self._on_remove_history_action),
             ('create-groupchat', self._on_create_groupchat_action),
             ('forget-groupchat', self._on_forget_groupchat_action),
-            ('groupchat-join', self._on_groupchat_join_action),
+            ('open-chat', self._on_open_chat_action),
             ('show', self._on_show),
         ]
 
@@ -446,7 +443,6 @@ class GajimApplication(Gtk.Application, CoreApplication):
     def _connect_account_actions(self, account: str) -> None:
         actions = [
             ('bookmarks', self._on_bookmarks_action),
-            ('open-chat', self._on_open_chat_action),
             ('add-contact', self._on_add_contact_account_action),
             ('services', self._on_services_action),
             ('profile', self._on_profile_action),
@@ -798,14 +794,6 @@ class GajimApplication(Gtk.Application, CoreApplication):
 
         app.window.mark_as_read(params.account, params.jid)
 
-    @staticmethod
-    def _on_open_mail_action(_action: Gio.SimpleAction,
-                             param: GLib.Variant) -> None:
-        uri = param.get_string()
-        if not uri.startswith('mailto:'):
-            uri = 'mailto:%s' % uri
-        open_uri(uri)
-
     @staticmethod
     def _on_open_link_action(_action: Gio.SimpleAction,
                              param: GLib.Variant) -> None:
@@ -863,12 +851,6 @@ class GajimApplication(Gtk.Application, CoreApplication):
 
         app.storage.archive.remove_history(params.account, params.jid)
 
-    @staticmethod
-    def _on_groupchat_join_action(_action: Gio.SimpleAction,
-                                  param: GLib.Variant) -> None:
-        account, jid = param.get_strv()
-        open_window('GroupchatJoin', account=account, jid=jid)
-
     @staticmethod
     def _on_show(_action: Gio.SimpleAction, param: GLib.Variant) -> None:
         app.window.show()
