@@ -17,41 +17,48 @@ from __future__ import annotations
 from typing import Optional
 from typing import Union
 
-import logging
+import functools
 import hashlib
-from math import pi
-from functools import lru_cache
+import logging
 from collections import defaultdict
+from math import pi
 from pathlib import Path
 
+import cairo
 from gi.repository import Gdk
 from gi.repository import GdkPixbuf
-import cairo
+from gi.repository import Pango
+from gi.repository import PangoCairo
 from nbxmpp.protocol import JID
 
-from gajim.common import types
 from gajim.common import app
 from gajim.common import configpaths
-from gajim.common.helpers import Singleton
-from gajim.common.helpers import get_groupchat_name
+from gajim.common import types
 from gajim.common.const import AvatarSize
 from gajim.common.const import StyleAttr
+from gajim.common.helpers import get_groupchat_name
+from gajim.common.util.classes import Singleton
 
 from .const import DEFAULT_WORKSPACE_COLOR
+from .util import convert_rgb_string_to_float
+from .util import get_contact_color
+from .util import get_css_show_class
+from .util import get_first_graphemes
 from .util import load_icon_surface
 from .util import load_pixbuf
-from .util import text_to_color
-from .util import scale_with_ratio
-from .util import get_css_show_class
-from .util import convert_rgb_string_to_float
-from .util import rgba_to_float
 from .util import make_rgba
+from .util import rgba_to_float
+from .util import scale_with_ratio
 
 log = logging.getLogger('gajim.gui.avatar')
 
 
-AvatarCacheT = dict[JID, dict[tuple[int, int, Optional[str]],
-                              cairo.ImageSurface]]
+AvatarCacheT = dict[Union[JID, str], dict[tuple[int, int, Optional[str]],
+                                          cairo.ImageSurface]]
+
+
+def generate_avatar_letter(text: str) -> str:
+    return get_first_graphemes(text.lstrip(), 1).upper()
 
 
 def generate_avatar(letters: str,
@@ -68,7 +75,7 @@ def generate_avatar(letters: str,
 
     width = size
     height = size
-    font_size = size * 0.5
+    font_size = size * 0.4
 
     # Set up surface
     surface = cairo.ImageSurface(cairo.Format.ARGB32, width, height)
@@ -79,41 +86,43 @@ def generate_avatar(letters: str,
     context.fill()
 
     # Draw letters
-    context.select_font_face('sans-serif',
-                             cairo.FontSlant.NORMAL,
-                             cairo.FontWeight.NORMAL)
-    context.set_font_size(font_size)
-    extends = context.text_extents(letters)
-    x_bearing = extends.x_bearing
-    y_bearing = extends.y_bearing
-    ex_width = extends.width
-    ex_height = extends.height
+    layout = PangoCairo.create_layout(context)
+    layout.set_text(generate_avatar_letter(letters))
+
+    description = Pango.FontDescription()
+    description.set_family('Sans')
+    description.set_size(int(font_size * Pango.SCALE))
+
+    layout.set_font_description(description)
+
+    _ink_rect, logical_rect = layout.get_extents()
+    layout_width = logical_rect.width / Pango.SCALE
+    layout_height = logical_rect.height / Pango.SCALE
+    x_pos = (width - layout_width) / 2
+    y_pos = (height - layout_height) / 2
 
-    x_pos = width / 2 - (ex_width / 2 + x_bearing)
-    y_pos = height / 2 - (ex_height / 2 + y_bearing)
     context.move_to(x_pos, y_pos)
     context.set_source_rgb(0.95, 0.95, 0.95)
     context.set_operator(cairo.Operator.OVER)
-    context.show_text(letters)
+    PangoCairo.show_layout(context, layout)
 
     return context.get_target()
 
 
-@lru_cache(maxsize=None)
+@functools.cache
 def generate_default_avatar(letter: str,
-                            color_string: str,
+                            color: tuple[float, float, float],
                             size: int,
                             scale: int,
                             style: str = 'circle') -> cairo.ImageSurface:
 
-    color = text_to_color(color_string)
     surface = generate_avatar(letter, color, size, scale)
     surface = clip(surface, style)
     surface.set_device_scale(scale, scale)
     return surface
 
 
-@lru_cache(maxsize=None)
+@functools.cache
 def make_workspace_avatar(letter: str,
                           color: tuple[float, float, float],
                           size: int,
@@ -121,13 +130,13 @@ def make_workspace_avatar(letter: str,
                           style: str = 'round-corners') -> cairo.ImageSurface:
 
     surface = generate_avatar(letter, color, size, scale)
-    surface = clip(surface, style)
     surface.set_device_scale(scale, scale)
-    return surface
+    return clip(surface, style)
 
 
 def add_status_to_avatar(surface: cairo.ImageSurface,
-                         show: str) -> cairo.ImageSurface:
+                         show: str
+                         ) -> cairo.ImageSurface:
 
     width = surface.get_width()
     height = surface.get_height()
@@ -177,8 +186,12 @@ def add_status_to_avatar(surface: cairo.ImageSurface,
     return context.get_target()
 
 
-@lru_cache(maxsize=128)
-def get_show_circle(show, size: int, scale: int) -> cairo.ImageSurface:
+@functools.lru_cache(maxsize=128)
+def get_show_circle(show: Union[str, types.PresenceShowT],
+                    size: int,
+                    scale: int
+                    ) -> cairo.ImageSurface:
+
     if not isinstance(show, str):
         show = show.value
 
@@ -288,23 +301,26 @@ def clip_circle(surface: cairo.ImageSurface) -> cairo.ImageSurface:
 
 
 def round_corners(surface: cairo.ImageSurface) -> cairo.ImageSurface:
-    new_surface = cairo.ImageSurface(cairo.Format.ARGB32,
-                                     surface.get_width(),
-                                     surface.get_height())
+    width = surface.get_width()
+    height = surface.get_height()
+    scale = surface.get_device_scale()[0]
 
+    new_surface = cairo.ImageSurface(cairo.Format.ARGB32,
+                                     width,
+                                     height)
     new_surface.set_device_scale(*surface.get_device_scale())
     context = cairo.Context(new_surface)
     context.set_source_surface(surface, 0, 0)
 
-    width = surface.get_width()
-    height = surface.get_height()
-    scale = surface.get_device_scale()[0]
-    radius = 9 * scale
+    width = width / scale
+    height = height / scale
+
+    radius = 9
     degrees = pi / 180
 
     context.new_sub_path()
     context.arc(width - radius, radius, radius, -90 * degrees, 0 * degrees)
-    context.arc(width - radius, height - radius, radius, 0 * degrees, 90 * degrees)
+    context.arc(width - radius, height - radius, radius, 0 * degrees, 90 * degrees)  # noqa: E501
     context.arc(radius, height - radius, radius, 90 * degrees, 180 * degrees)
     context.arc(radius, radius, radius, 180 * degrees, 270 * degrees)
     context.close_path()
@@ -332,7 +348,7 @@ class AvatarStorage(metaclass=Singleton):
     def __init__(self):
         self._cache: AvatarCacheT = defaultdict(dict)
 
-    def invalidate_cache(self, jid: JID) -> None:
+    def invalidate_cache(self, jid: Union[JID, str]) -> None:
         self._cache.pop(jid, None)
 
     def get_pixbuf(self,
@@ -348,7 +364,11 @@ class AvatarStorage(metaclass=Singleton):
 
         surface = self.get_surface(
             contact, size, scale, show, default, transport_icon, style)
-        return Gdk.pixbuf_get_from_surface(surface, 0, 0, size, size)
+        return Gdk.pixbuf_get_from_surface(surface,
+                                           0,
+                                           0,
+                                           size * scale,
+                                           size * scale)
 
     def get_surface(self,
                     contact: Union[types.BareContact,
@@ -365,6 +385,7 @@ class AvatarStorage(metaclass=Singleton):
 
         if transport_icon is not None:
             surface = load_icon_surface(transport_icon, size, scale)
+            assert surface is not None
             if show is not None:
                 surface = add_status_to_avatar(surface, show)
             self._cache[jid][(size, scale, show)] = surface
@@ -383,11 +404,10 @@ class AvatarStorage(metaclass=Singleton):
                 return surface
 
         name = contact.name
-        color_string = str(contact.jid)
-
-        letter = self._generate_letter(name)
+        color = get_contact_color(contact)
+        letter = generate_avatar_letter(name)
         surface = generate_default_avatar(
-            letter, color_string, size, scale, style=style)
+            letter, color, size, scale, style=style)
         if show is not None:
             surface = add_status_to_avatar(surface, show)
         self._cache[jid][(size, scale, show)] = surface
@@ -404,11 +424,12 @@ class AvatarStorage(metaclass=Singleton):
 
         if transport_icon is not None:
             surface = load_icon_surface(transport_icon, size, scale)
-            self._cache[jid][(size, scale)] = surface
+            assert surface is not None
+            self._cache[jid][(size, scale, None)] = surface
             return surface
 
         if not default:
-            surface = self._cache[jid].get((size, scale))
+            surface = self._cache[jid].get((size, scale, None))
             if surface is not None:
                 return surface
 
@@ -417,18 +438,21 @@ class AvatarStorage(metaclass=Singleton):
                 surface = self.surface_from_filename(avatar_sha, size, scale)
                 if surface is not None:
                     surface = clip(surface, style)
-                    self._cache[jid][(size, scale)] = surface
+                    self._cache[jid][(size, scale, None)] = surface
                     return surface
 
                 # avatar_sha set, but image is missing
                 # (e.g. avatar cache deleted)
                 app.storage.cache.set_muc(jid, 'avatar', None)
 
-        con = app.connections[account]
-        name = get_groupchat_name(con, jid)
-        letter = self._generate_letter(name)
-        surface = generate_default_avatar(letter, str(jid), size, scale, style)
-        self._cache[jid][(size, scale)] = surface
+        client = app.get_client(account)
+        contact = client.get_module('Contacts').get_bare_contact(jid)
+
+        name = get_groupchat_name(client, jid)
+        color = get_contact_color(contact)
+        letter = generate_avatar_letter(name)
+        surface = generate_default_avatar(letter, color, size, scale, style)
+        self._cache[jid][(size, scale, None)] = surface
         return surface
 
     def get_workspace_surface(self,
@@ -436,7 +460,7 @@ class AvatarStorage(metaclass=Singleton):
                               size: int,
                               scale: int) -> Optional[cairo.ImageSurface]:
 
-        surface = self._cache[workspace_id].get((size, scale))
+        surface = self._cache[workspace_id].get((size, scale, None))
         if surface is not None:
             return surface
 
@@ -454,10 +478,9 @@ class AvatarStorage(metaclass=Singleton):
             app.settings.set_workspace_setting(workspace_id, 'avatar_sha', '')
 
         rgba = make_rgba(color or DEFAULT_WORKSPACE_COLOR)
-        letter = name[:1].upper()
         surface = make_workspace_avatar(
-            letter, rgba_to_float(rgba), size, scale)
-        self._cache[workspace_id][(size, scale)] = surface
+            name, rgba_to_float(rgba), size, scale)
+        self._cache[workspace_id][(size, scale, None)] = surface
         return surface
 
     @staticmethod
@@ -475,17 +498,18 @@ class AvatarStorage(metaclass=Singleton):
                                          height,
                                          GdkPixbuf.InterpType.BILINEAR)
 
+        assert pixbuf is not None
         return pixbuf.save_to_bufferv('png', [], [])
 
     @staticmethod
     def save_avatar(data: bytes) -> Optional[str]:
-        """
+        '''
         Save an avatar to the harddisk
 
         :param data:  bytes
 
         returns SHA1 value of the avatar or None on error
-        """
+        '''
         if data is None:
             return None
 
@@ -506,6 +530,9 @@ class AvatarStorage(metaclass=Singleton):
             return None
         return path
 
+    def avatar_exists(self, filename: str) -> bool:
+        return self.get_avatar_path(filename) is not None
+
     def surface_from_filename(self,
                               filename: str,
                               size: int,
@@ -555,10 +582,3 @@ class AvatarStorage(metaclass=Singleton):
         if surface is None:
             return None
         return clip(surface, style)
-
-    @staticmethod
-    def _generate_letter(name: str) -> str:
-        for letter in name:
-            if letter.isalpha():
-                return letter.capitalize()
-        return name[0].capitalize()
