@@ -22,7 +22,6 @@ from pathlib import Path
 from gi.repository import GObject
 from gi.repository import Gtk
 from gi.repository import Pango
-
 from nbxmpp.protocol import InvalidJid
 from nbxmpp.protocol import JID
 from nbxmpp.protocol import validate_resourcepart
@@ -44,7 +43,7 @@ class FunctionMode(Enum):
     CHANGE_NICKNAME = 'change-nickname'
     KICK = 'kick'
     BAN = 'ban'
-    PASSWORD_REQUEST = 'password-request'
+    PASSWORD_REQUEST = 'password-request'  # noqa: S105
     CAPTCHA_REQUEST = 'captcha-request'
     CAPTCHA_ERROR = 'captcha-error'
     JOIN_FAILED = 'join-failed'
