@@ -14,31 +14,28 @@
 
 from __future__ import annotations
 
-from typing import TYPE_CHECKING
+from typing import Any
+from typing import Callable
 from typing import Optional
 
 from datetime import datetime
 
-from gi.repository import Gtk
-from gi.repository import Gdk
-from gi.repository import Pango
-from gi.repository import GLib
 import cairo
+from gi.repository import Gdk
+from gi.repository import GLib
+from gi.repository import Gtk
+from gi.repository import Pango
 
 from gajim.common import app
 from gajim.common.const import AvatarSize
-from gajim.common.i18n import Q_
+from gajim.common.i18n import p_
 from gajim.common.modules.contacts import GroupchatContact
 from gajim.common.types import ChatContactT
 
-if TYPE_CHECKING:
-    from .message import MessageRow
-
-from ...menus import get_chat_row_menu
 from ...menus import get_groupchat_participant_menu
-from ...util import wrap_with_event_box
-from ...util import get_cursor
 from ...util import GajimPopover
+from ...util import get_cursor
+from ...util import wrap_with_event_box
 
 
 class SimpleLabel(Gtk.Label):
@@ -52,11 +49,7 @@ class SimpleLabel(Gtk.Label):
 
 @wrap_with_event_box
 class MoreMenuButton(Gtk.Button):
-    def __init__(self,
-                 row: MessageRow,
-                 contact: ChatContactT,
-                 name: str
-                 ) -> None:
+    def __init__(self, on_click_handler: Callable[[Gtk.Button], Any]) -> None:
 
         Gtk.Button.__init__(self)
         self.set_valign(Gtk.Align.START)
@@ -66,46 +59,28 @@ class MoreMenuButton(Gtk.Button):
 
         self.get_style_context().add_class('conversation-more-button')
 
-        self._row = row
-        self._contact = contact
-        self._name = name
-
         image = Gtk.Image.new_from_icon_name(
             'feather-more-horizontal-symbolic', Gtk.IconSize.BUTTON)
         self.add(image)
-        self.connect('clicked', self._on_click)
-
-    def _on_click(self, _button: Gtk.Button) -> None:
-        menu = get_chat_row_menu(
-            self._contact,
-            self._name,
-            self._row.get_text(),
-            self._row.timestamp,
-            self._row.message_id,
-            self._row.stanza_id,
-            self._row.log_line_id)
-
-        popover = GajimPopover(menu, relative_to=self)
-        popover.popup()
+        self.connect('clicked', on_click_handler)
 
 
 class DateTimeLabel(Gtk.Label):
     def __init__(self, timestamp: datetime) -> None:
         Gtk.Label.__init__(self)
 
-        time_format = app.settings.get('time_format')
+        format_string = app.settings.get('time_format')
         if timestamp.date() < datetime.today().date():
-            date_format = app.settings.get('date_format')
-            time_format = f'{time_format} - {date_format}'
-        timestamp_formatted = timestamp.strftime(time_format)
+            format_string = app.settings.get('date_time_format')
 
-        self.set_text(timestamp_formatted)
+        self.set_text(timestamp.strftime(format_string))
         self.set_halign(Gtk.Align.START)
         self.set_valign(Gtk.Align.END)
         self.set_margin_start(6)
         self.set_margin_end(3)
         self.get_style_context().add_class('conversation-meta')
-        self.set_tooltip_text(timestamp.strftime('%a, %d %b %Y - %X'))
+        format_string = app.settings.get('date_time_format')
+        self.set_tooltip_text(timestamp.strftime(format_string))
 
 
 class NicknameLabel(Gtk.Label):
@@ -155,7 +130,7 @@ class MessageIcons(Gtk.Box):
         self._marker_image.set_visible(visible)
         self._marker_image.set_from_icon_name(
             'feather-check-symbolic', Gtk.IconSize.MENU)
-        self._marker_image.set_tooltip_text(Q_('?Message state:Received'))
+        self._marker_image.set_tooltip_text(p_('Message state', 'Received'))
 
     def set_correction_icon_visible(self, visible: bool) -> None:
         self._correction_image.set_visible(visible)
