@@ -16,49 +16,47 @@
 
 from __future__ import annotations
 
-from typing import Iterator
+from typing import Callable
 from typing import cast
+from typing import Iterator
 from typing import Optional
-from typing import Union
 
-from datetime import datetime
 import textwrap
+from datetime import datetime
 from urllib.parse import quote
 
-from gi.repository import Gtk
 from gi.repository import Gio
 from gi.repository import GLib
-
+from gi.repository import Gtk
 from nbxmpp import JID
 
 from gajim.common import app
 from gajim.common import types
-from gajim.common.helpers import from_one_line
+from gajim.common.const import URIType
+from gajim.common.const import XmppUriQuery
+from gajim.common.helpers import filesystem_path_from_uri
 from gajim.common.helpers import is_affiliation_change_allowed
 from gajim.common.helpers import is_retraction_allowed
 from gajim.common.helpers import is_role_change_allowed
 from gajim.common.helpers import jid_is_blocked
 from gajim.common.i18n import _
-from gajim.common.i18n import Q_
 from gajim.common.i18n import get_short_lang_code
-from gajim.common.const import URIType
-from gajim.common.const import XmppUriQuery
+from gajim.common.i18n import p_
+from gajim.common.modules.contacts import can_add_to_roster
+from gajim.common.modules.contacts import GroupchatContact
 from gajim.common.preview import Preview
 from gajim.common.structs import URI
-from gajim.common.structs import VariantMixin
-from gajim.common.modules.contacts import GroupchatContact
-from gajim.common.modules.contacts import can_add_to_roster
-
-from gajim.gui.structs import AddChatActionParams
+from gajim.common.util.text import escape_iri_path_segment
 from gajim.gui.structs import AccountJidParam
+from gajim.gui.structs import AddChatActionParams
 from gajim.gui.structs import ChatListEntryParam
 from gajim.gui.structs import RemoveHistoryActionParams
 from gajim.gui.structs import RetractMessageParam
 from gajim.gui.util import GajimMenu
+from gajim.gui.util import MenuItemListT
 
-
-MenuValueT = Union[None, str, GLib.Variant, VariantMixin]
-MenuItemListT = list[tuple[str, str, MenuValueT]]
+UriMenuItemsT = list[tuple[str, list[str], str]]
+UriMenuBuilderT = Callable[[URI, str], UriMenuItemsT]
 
 
 def get_self_contact_menu(contact: types.BareContact) -> GajimMenu:
@@ -67,7 +65,7 @@ def get_self_contact_menu(contact: types.BareContact) -> GajimMenu:
 
     menu = GajimMenu()
 
-    menu.add_item(_('Profile'), f'app.{account}-profile', f'"{account}"')
+    menu.add_item(_('Profile'), f'app.{account}-profile', account)
     submenu = get_send_file_submenu()
     menu.append_submenu(_('Send File'), submenu)
 
@@ -80,11 +78,11 @@ def get_self_contact_menu(contact: types.BareContact) -> GajimMenu:
 def get_singlechat_menu(contact: types.BareContact) -> GajimMenu:
     account = contact.account
 
-    value = f'"{contact.jid}"'
-
     menu = GajimMenu()
     menu.add_item(_('Details'), 'win.show-contact-info')
-    menu.add_item(_('Block Contact…'), f'app.{account}-block-contact', value)
+    menu.add_item(_('Block Contact…'),
+                  f'app.{account}-block-contact',
+                  str(contact.jid))
 
     submenu = get_send_file_submenu()
     menu.append_submenu(_('Send File'), submenu)
@@ -103,8 +101,11 @@ def get_singlechat_menu(contact: types.BareContact) -> GajimMenu:
 
 def get_private_chat_menu(contact: types.GroupchatParticipant) -> GajimMenu:
     menu = GajimMenu()
+
+    value = GLib.Variant('as', [''])
+
     menu.add_item(_('Details'), 'win.show-contact-info')
-    menu.add_item(_('Upload File…'), 'win.send-file-httpupload([""])')
+    menu.add_item(_('Upload File…'), 'win.send-file-httpupload', value)
     menu.add_item(_('Search…'), 'win.search-history')
 
     if can_add_to_roster(contact):
@@ -117,8 +118,10 @@ def get_private_chat_menu(contact: types.GroupchatParticipant) -> GajimMenu:
 def get_send_file_submenu() -> GajimMenu:
     menu = GajimMenu()
 
-    menu.add_item(_('Upload File…'), 'win.send-file-httpupload([""])')
-    menu.add_item(_('Send File Directly…'), 'win.send-file-jingle([""])')
+    value = GLib.Variant('as', [''])
+
+    menu.add_item(_('Upload File…'), 'win.send-file-httpupload', value)
+    menu.add_item(_('Send File Directly…'), 'win.send-file-jingle', value)
     return menu
 
 
@@ -127,7 +130,7 @@ def get_groupchat_menu(contact: GroupchatContact) -> GajimMenu:
         (_('Details'), 'win.show-contact-info', None),
         (_('Change Nickname…'), 'win.muc-change-nickname', None),
         (_('Request Voice'), 'win.muc-request-voice', None),
-        (_('Execute Command…'), 'win.muc-execute-command', '""'),
+        (_('Execute Command…'), 'win.muc-execute-command', ''),
         (_('Search…'), 'win.search-history', None)
     ]
 
@@ -136,26 +139,24 @@ def get_groupchat_menu(contact: GroupchatContact) -> GajimMenu:
 
 def get_account_menu(account: str) -> GajimMenu:
 
-    val = f'"{account}"'
-
     menuitems: MenuItemListT = [
-        (_('Profile'), f'app.{account}-profile', val),
-        (_('Discover Services…'), f'app.{account}-services', val),
-        (_('Server Info'), f'app.{account}-server-info', val),
+        (_('Profile'), f'app.{account}-profile', account),
+        (_('Discover Services…'), f'app.{account}-services', account),
+        (_('Server Info'), f'app.{account}-server-info', account),
     ]
 
     menu = GajimMenu.from_list(menuitems)
 
     advanced_menuitems: MenuItemListT = [
-        (_('Archiving Preferences'), f'app.{account}-archive', val),
-        (_('Blocking List'), f'app.{account}-blocking', val),
-        (_('PEP Configuration'), f'app.{account}-pep-config', val),
-        (_('Synchronise History…'), f'app.{account}-sync-history', val),
+        (_('Archiving Preferences'), f'app.{account}-archive', account),
+        (_('Blocking List'), f'app.{account}-blocking', account),
+        (_('PEP Configuration'), f'app.{account}-pep-config', account),
+        (_('Synchronise History…'), f'app.{account}-sync-history', account),
     ]
 
     if app.settings.get('developer_modus'):
         advanced_menuitems.append(
-            (_('Bookmarks'), f'app.{account}-bookmarks', val))
+            (_('Bookmarks'), f'app.{account}-bookmarks', account))
 
     menu.append_submenu(_('Advanced'), GajimMenu.from_list(advanced_menuitems))
 
@@ -204,10 +205,10 @@ def build_accounts_menu() -> None:
 def get_encryption_menu() -> GajimMenu:
 
     menuitems: MenuItemListT = [
-        (_('Disabled'), 'win.set-encryption', '""'),
-        ('OMEMO', 'win.set-encryption', '"OMEMO"'),
-        ('OpenPGP', 'win.set-encryption', '"OpenPGP"'),
-        ('PGP', 'win.set-encryption', '"PGP"'),
+        (_('Disabled'), 'win.set-encryption', ''),
+        ('OMEMO', 'win.set-encryption', 'OMEMO'),
+        ('OpenPGP', 'win.set-encryption', 'OpenPGP'),
+        ('PGP', 'win.set-encryption', 'PGP'),
     ]
 
     return GajimMenu.from_list(menuitems)
@@ -285,77 +286,124 @@ def get_conv_action_context_menu(account: str,
     return action_menu_item
 
 
-def get_conv_uri_context_menu(account: str, uri: URI) -> Optional[Gtk.Menu]:
-    if uri.type == URIType.XMPP:
-        if XmppUriQuery.from_str(uri.query_type) == XmppUriQuery.JOIN:
-            context_menu = [
-                ('copy-text', _('Copy XMPP Address')),
-                ('groupchat-join', _('Join Groupchat')),
-            ]
-        else:
-            context_menu = [
-                ('copy-text', _('Copy XMPP Address')),
-                ('-open-chat', _('Start Chat')),
-                ('-add-contact', _('Add to Contact List…')),
-            ]
+def _xmpp_message_query_context_menu(uri: URI, account: str) -> UriMenuItemsT:
+    jid = uri.data['jid']
+    # qparams = uri.query_params
+    return [
+        ('copy-text', [uri.source], _('Copy Link Location')),
+        ('copy-text', [jid], _('Copy XMPP Address')),
+        ('open-chat', [account, jid], _('Start Chat…')),
+        # ^ TODO: pass qparams ^
+        (f'{account}-add-contact', [account, jid], _('Add to Contact List…')),
+    ]
 
-    elif uri.type == URIType.WEB:
-        context_menu = [
-            ('copy-text', _('Copy Link Location')),
-            ('open-link', _('Open Link in Browser')),
-        ]
 
-    elif uri.type == URIType.MAIL:
-        context_menu = [
-            ('copy-text', _('Copy Email Address')),
-            ('open-mail', _('Open Email Composer')),
-        ]
+def _xmpp_join_query_context_menu(uri: URI, account: str) -> UriMenuItemsT:
+    return [
+        ('copy-text', [uri.source], _('Copy Link Location')),
+        ('copy-text', [uri.data['jid']], _('Copy XMPP Address')),
+        ('open-chat', [account, uri.data['jid']],
+            # ^ TODO: pass qparams ^
+            _('Join Groupchat…')),
+    ]
 
-    elif uri.type == URIType.GEO:
-        context_menu = [
-            ('copy-text', _('Copy Location')),
-            ('open-link', _('Show Location')),
-        ]
 
-    elif uri.type == URIType.AT:
-        context_menu = [
-            ('copy-text', _('Copy XMPP Address/Email')),
-            ('open-mail', _('Open Email Composer')),
-            ('-open-chat', _('Start Chat')),
-            ('groupchat-join', _('Join Groupchat')),
-            ('-add-contact', _('Add to Contact List…')),
-        ]
-    else:
-        return None
+_xmpp_uri_context_menus: dict[XmppUriQuery, UriMenuBuilderT] = {
+    XmppUriQuery.NONE: _xmpp_message_query_context_menu,
+    XmppUriQuery.MESSAGE: _xmpp_message_query_context_menu,
+    XmppUriQuery.JOIN: _xmpp_join_query_context_menu,
+}
 
-    menu = Gtk.Menu()
-    for item in context_menu:
-        action, label = item
+
+def _xmpp_uri_context_menu(uri: URI, account: str) -> UriMenuItemsT:
+    return _xmpp_uri_context_menus[XmppUriQuery.from_str_or_none(uri.query_type)
+                                   ](uri, account)
+
+
+def _web_uri_context_menu(uri: URI, _account: str) -> UriMenuItemsT:
+    return [
+        ('copy-text', [uri.source], _('Copy Link Location')),
+        ('open-link', ['', uri.source], _('Open Link in Browser')),
+    ]
+
+
+def _mailto_uri_context_menu(uri: URI, _account: str) -> UriMenuItemsT:
+    return [
+        ('copy-text', [uri.source], _('Copy Link Location')),
+        ('copy-text', [uri.data['addr']], _('Copy Email Address')),
+        ('open-link', ['', uri.source], _('Open Email Composer')),
+    ]
+
+
+def _geo_uri_context_menu(uri: URI, _account: str) -> UriMenuItemsT:
+    return [
+        ('copy-text', [uri.source], _('Copy Link Location')),
+        ('open-link', ['', uri.source], _('Show Location')),
+    ]
+
+
+def _ambiguous_addr_context_menu(uri: URI, account: str) -> UriMenuItemsT:
+    addr = uri.data['addr']
+    mailto = 'mailto:' + escape_iri_path_segment(addr)
+    return [
+        ('copy-text', [addr], _('Copy XMPP Address/Email')),
+        ('open-link', ['', mailto], _('Open Email Composer')),
+        ('open-chat', [account, addr], _('Start Chat…')),
+        (f'{account}-add-contact', [account, addr], _('Add to Contact List…')),
+    ]
+
+
+def _file_uri_context_menu(uri: URI, _account: str) -> UriMenuItemsT:
+    canopen = app.settings.get('allow_open_file_uris')
+    pathobj = filesystem_path_from_uri(uri.source)
+    return [
+        ('copy-text', [uri.source], _('Copy Link Location')),
+        ('open-link' if canopen else '-', ['', uri.source], _('Open Path')),
+        ('copy-text' if pathobj else '-', [str(pathobj)], _('Copy Path')),
+    ]
+
+
+def _tel_uri_context_menu(uri: URI, account: str) -> UriMenuItemsT:
+    return [
+        ('copy-text', [uri.source], _('Copy Link Location')),
+        ('open-link', [account, uri.source], _('Dial Number')),
+        # TODO:
+        # ('copy-text', [uri.data['number']], _('Copy Number')),
+    ]
+
+
+def _other_uri_context_menu(uri: URI, account: str) -> UriMenuItemsT:
+    return [
+        ('copy-text', [uri.source], _('Copy Link Location')),
+        ('open-link', [account, uri.source], _('Open Link')),
+    ]
+
+
+_uri_context_menus: dict[URIType, UriMenuBuilderT] = {
+    URIType.XMPP: _xmpp_uri_context_menu,
+    URIType.MAIL: _mailto_uri_context_menu,
+    URIType.GEO: _geo_uri_context_menu,
+    URIType.WEB: _web_uri_context_menu,
+    URIType.FILE: _file_uri_context_menu,
+    URIType.AT: _ambiguous_addr_context_menu,
+    URIType.TEL: _tel_uri_context_menu,
+    URIType.OTHER: _other_uri_context_menu,
+}
+
+
+def populate_uri_context_menu(menu: Gtk.Menu, account: str, uri: URI) -> None:
+    assert uri.type != URIType.INVALID  # it really begs to be a separate class
+    for action, args, label in _uri_context_menus[uri.type](uri, account):
         menuitem = Gtk.MenuItem()
         menuitem.set_label(label)
-
-        if action.startswith('-'):
-            action = f'app.{account}{action}'
+        menuitem.set_action_name(f'app.{action}')
+        if len(args) == 1:
+            value = GLib.Variant.new_string(args[0])
         else:
-            action = f'app.{action}'
-        menuitem.set_action_name(action)
-
-        data = uri.data
-        if uri.type == URIType.XMPP:
-            if isinstance(uri.data, dict):
-                data = uri.data['jid']
-            else:
-                data = ''
-        assert isinstance(data, str)
-
-        if action in ('app.open-mail', 'app.copy-text'):
-            value = GLib.Variant.new_string(data)
-        else:
-            value = GLib.Variant.new_strv([account, data])
+            value = GLib.Variant.new_strv(args)
         menuitem.set_action_target_value(value)
         menuitem.show()
         menu.append(menuitem)
-    return menu
 
 
 def get_roster_menu(account: str, jid: str, gateway: bool = False) -> GajimMenu:
@@ -364,7 +412,7 @@ def get_roster_menu(account: str, jid: str, gateway: bool = False) -> GajimMenu:
     if jid_is_blocked(account, jid):
         block_label = _('Unblock')
 
-    value = f'"{jid}"'
+    value = str(jid)
 
     menuitems: MenuItemListT = [
         (_('Details'), f'app.{account}-contact-info', value),
@@ -394,7 +442,7 @@ def get_subscription_menu(account: str, jid: JID) -> GajimMenu:
                                  jid=jid,
                                  type='contact',
                                  select=True)
-    value = f'"{jid}"'
+    value = str(jid)
     menuitems: MenuItemListT = [
         (_('Start Chat'), 'win.add-chat', params),
         (_('Details'), f'win.contact-info-{account}', value),
@@ -407,10 +455,13 @@ def get_subscription_menu(account: str, jid: JID) -> GajimMenu:
 
 
 def get_start_chat_button_menu() -> GajimMenu:
+
+    value = GLib.Variant('as', ['', ''])
+
     menuitems: MenuItemListT = [
-        (_('Start Chat…'), 'app.start-chat(["", ""])', None),
-        (_('Create Group Chat…'), 'app.create-groupchat::', None),
-        (_('Add Contact…'), 'app.add-contact::', None),
+        (_('Start Chat…'), 'app.start-chat', value),
+        (_('Create Group Chat…'), 'app.create-groupchat', ''),
+        (_('Add Contact…'), 'app.add-contact', ''),
     ]
 
     return GajimMenu.from_list(menuitems)
@@ -494,26 +545,26 @@ def get_groupchat_admin_menu(self_contact: types.GroupchatParticipant,
         return menu
 
     action = 'win.muc-change-affiliation'
+    real_jid = str(contact.real_jid)
 
     if is_affiliation_change_allowed(self_contact, contact, 'owner'):
-        value = f'["{contact.real_jid}", "owner"]'
+        value = GLib.Variant('as', [real_jid, 'owner'])
         menu.add_item(_('Make Owner'), action, value)
 
     if is_affiliation_change_allowed(self_contact, contact, 'admin'):
-        value = f'["{contact.real_jid}", "admin"]'
+        value = GLib.Variant('as', [real_jid, 'admin'])
         menu.add_item(_('Make Admin'), action, value)
 
     if is_affiliation_change_allowed(self_contact, contact, 'member'):
-        value = f'["{contact.real_jid}", "member"]'
+        value = GLib.Variant('as', [real_jid, 'member'])
         menu.add_item(_('Make Member'), action, value)
 
     if is_affiliation_change_allowed(self_contact, contact, 'none'):
-        value = f'["{contact.real_jid}", "none"]'
+        value = GLib.Variant('as', [real_jid, 'none'])
         menu.add_item(_('Revoke Member'), action, value)
 
     if is_affiliation_change_allowed(self_contact, contact, 'outcast'):
-        value = f'"{contact.real_jid}"'
-        menu.add_item(_('Ban…'), 'win.muc-ban', value)
+        menu.add_item(_('Ban…'), 'win.muc-ban', real_jid)
 
     if not menu.get_n_items():
         menu.add_item(_('Not Available'), 'dummy', None)
@@ -531,18 +582,19 @@ def get_groupchat_mod_menu(self_contact: types.GroupchatParticipant,
         menu.add_item(_('Not Available'), 'dummy', None)
         return menu
 
+    contact_name = str(contact.name)
+
     if is_role_change_allowed(self_contact, contact):
-        value = f'"{contact.name}"'
-        menu.add_item(_('Kick…'), 'win.muc-kick', value)
+        menu.add_item(_('Kick…'), 'win.muc-kick', contact_name)
 
     action = 'win.muc-change-role'
 
     if is_role_change_allowed(self_contact, contact):
         if contact.role.is_visitor:
-            value = f'["{contact.name}", "participant"]'
+            value = GLib.Variant('as', [contact_name, 'participant'])
             menu.add_item(_('Grant Voice'), action, value)
         else:
-            value = f'["{contact.name}", "visitor"]'
+            value = value = GLib.Variant('as', [contact_name, 'visitor'])
             menu.add_item(_('Revoke Voice'), action, value)
 
     if not menu.get_n_items():
@@ -556,7 +608,7 @@ def get_groupchat_participant_menu(account: str,
                                    contact: types.GroupchatParticipant
                                    ) -> GajimMenu:
 
-    value = f'"{contact.name}"'
+    value = str(contact.name)
 
     general_items: MenuItemListT = [
         (_('Details'), 'win.muc-contact-info', value),
@@ -565,7 +617,7 @@ def get_groupchat_participant_menu(account: str,
 
     real_contact = contact.get_real_contact()
     if real_contact is not None and can_add_to_roster(real_contact):
-        value = f'["{account}", "{real_contact.jid}"]'
+        value = GLib.Variant('as', [account, str(real_contact.jid)])
         action = f'app.{account}-add-contact'
         general_items.insert(1, (_('Add to Contact List…'), action, value))
 
@@ -578,26 +630,17 @@ def get_groupchat_participant_menu(account: str,
     return menu
 
 
-def get_component_search_menu(jid: Optional[str], copy_text: str) -> Gio.Menu:
-    menu_items: list[tuple[str, str]] = [
-        ('app.copy-text', _('Copy')),
+def get_component_search_menu(jid: Optional[str], copy_text: str) -> GajimMenu:
+    menuitems: MenuItemListT = [
+        (_('Copy'), 'app.copy-text', copy_text),
     ]
-    if jid is not None:
-        menu_items.append(
-            ('app.start-chat', _('Start Chat…')))
 
-    menu = Gio.Menu()
-    for item in menu_items:
-        action, label = item
-        menuitem = Gio.MenuItem.new(label, action)
-        if action == 'app.copy-text':
-            data = copy_text
-        else:
-            data = jid
-        variant = GLib.Variant('s', data)
-        menuitem.set_action_and_target_value(action, variant)
-        menu.append_item(menuitem)
-    return menu
+    if jid is not None:
+        menuitems.append(
+            (_('Start Chat…'), 'app.start-chat', jid)
+        )
+
+    return GajimMenu.from_list(menuitems)
 
 
 def get_chat_row_menu(contact: types.ChatContactT,
@@ -611,16 +654,16 @@ def get_chat_row_menu(contact: types.ChatContactT,
 
     menu_items: MenuItemListT = []
 
-    text = text.replace('"', '\\"')
-
-    time_format = from_one_line(app.settings.get('time_format'))
-    timestamp_formatted = timestamp.strftime(time_format)
+    format_string = app.settings.get('date_time_format')
+    timestamp_formatted = timestamp.strftime(format_string)
     copy_text = f'{timestamp_formatted} - {name}: {text}'
     menu_items.append(
-        (Q_('?Message row action:Copy'), 'win.copy-message', f'"{copy_text}"'))
+        (p_('Message row action', 'Copy'),
+         'win.copy-message',
+         copy_text))
 
     menu_items.append(
-        (Q_('?Message row action:Select Messages…'),
+        (p_('Message row action', 'Select Messages…'),
          'win.activate-message-selection',
          GLib.Variant('u', log_line_id or 0)))
 
@@ -634,9 +677,7 @@ def get_chat_row_menu(contact: types.ChatContactT,
             show_quote = False
     if show_quote:
         menu_items.append((
-            Q_('?Message row action:Quote…'),
-            'win.quote',
-            f'"{text}"'))
+            p_('Message row action', 'Quote…'), 'win.quote', text))
 
     show_correction = False
     if message_id is not None:
@@ -644,7 +685,7 @@ def get_chat_row_menu(contact: types.ChatContactT,
             contact, message_id)
     if show_correction:
         menu_items.append((
-            Q_('?Message row action:Correct…'), 'win.correct-message', None))
+            p_('Message row action', 'Correct…'), 'win.correct-message', None))
 
     show_retract = False
     if isinstance(contact, GroupchatContact) and contact.is_joined:
@@ -665,23 +706,23 @@ def get_chat_row_menu(contact: types.ChatContactT,
             jid=contact.jid,
             stanza_id=stanza_id)
         menu_items.append((
-            Q_('?Message row action:Retract…'), 'win.retract-message', param))
+            p_('Message row action', 'Retract…'),
+            'win.retract-message',
+            param))
 
-    menu = GajimMenu.from_list(menu_items)
-    return menu
+    return GajimMenu.from_list(menu_items)
 
 
 def get_preview_menu(preview: Preview) -> GajimMenu:
     menu_items: MenuItemListT = []
 
-    variant = GLib.Variant('s', preview.id)
-
-    download = (_('_Download'), 'win.preview-download', variant)
-    open_file = (_('_Open'), 'win.preview-open', variant)
-    save_as = (_('_Save as…'), 'win.preview-save-as', variant)
-    open_folder = (_('Open _Folder'), 'win.preview-open-folder', variant)
-    copy_link = (_('_Copy Link'), 'win.preview-copy-link', variant)
-    open_link = (_('Open Link in _Browser'), 'win.preview-open-link', variant)
+    download = (_('_Download'), 'win.preview-download', preview.id)
+    open_file = (_('_Open'), 'win.preview-open', preview.id)
+    save_as = (_('_Save as…'), 'win.preview-save-as', preview.id)
+    open_folder = (_('Open _Folder'), 'win.preview-open-folder', preview.id)
+    copy_link = (_('_Copy Link'), 'win.preview-copy-link', preview.id)
+    open_link = (_('Open Link in _Browser'), 'win.preview-open-link',
+                 preview.id)
 
     if preview.is_geo_uri:
         menu_items.append(open_file)
@@ -721,8 +762,8 @@ def get_workspace_menu(workspace_id: str, has_unread: bool) -> GajimMenu:
         remove_action = 'win.remove-workspace'
 
     menuitems: MenuItemListT = [
-        (_('Edit…'), 'win.edit-workspace', f'"{workspace_id}"'),
-        (_('Remove'), remove_action, f'"{workspace_id}"'),
+        (_('Edit…'), 'win.edit-workspace', workspace_id),
+        (_('Remove'), remove_action, workspace_id),
     ]
 
     if has_unread:
@@ -730,7 +771,7 @@ def get_workspace_menu(workspace_id: str, has_unread: bool) -> GajimMenu:
             0,
             (_('Mark as read'),
              'win.mark-workspace-as-read',
-             f'"{workspace_id}"'))
+             workspace_id))
 
     return GajimMenu.from_list(menuitems)
 
