@@ -22,23 +22,22 @@ from __future__ import annotations
 from typing import Any
 from typing import Optional
 
+import logging
 from collections import defaultdict
 
-import logging
-
-from gi.repository import Gtk
 from gi.repository import Gdk
 from gi.repository import GLib
+from gi.repository import Gtk
 from gi.repository import Pango
 
 from gajim.common import app
 from gajim.common import ged
 from gajim.common.events import MessageSent
 from gajim.common.ged import EventHelper
-from gajim.common.i18n import LANG
 from gajim.common.i18n import _
-from gajim.common.styling import process
+from gajim.common.i18n import LANG
 from gajim.common.styling import PlainBlock
+from gajim.common.styling import process
 from gajim.common.types import ChatContactT
 
 from .chat_action_processor import ChatActionProcessor
@@ -225,7 +224,7 @@ class MessageInputTextView(Gtk.TextView, EventHelper):
         assert isinstance(lang, str)
         lang = Gspell.language_lookup(lang)
         if lang is None:
-            lang = Gspell.language_get_default()
+            return Gspell.language_get_default()
         return lang
 
     def _on_language_changed(self,
@@ -347,8 +346,7 @@ class MessageInputTextView(Gtk.TextView, EventHelper):
     def get_text(self) -> str:
         buf = self.get_buffer()
         start, end = buf.get_bounds()
-        text = self.get_buffer().get_text(start, end, True)
-        return text
+        return self.get_buffer().get_text(start, end, True)
 
     def _on_toggle_spell_check(self, *args: Any) -> None:
         if not app.is_installed('GSPELL'):
