@@ -30,34 +30,35 @@ from typing import Any
 from typing import Optional
 from typing import Union
 
-import sys
 import logging
+import sys
+import textwrap
 
-from gi.repository import GLib
-from gi.repository import Gio
 from gi.repository import Gdk
 from gi.repository import GdkPixbuf
+from gi.repository import Gio
+from gi.repository import GLib
 from gi.repository import Gtk
 from nbxmpp.protocol import JID
 
 from gajim.common import app
-from gajim.common import ged
 from gajim.common import events
+from gajim.common import ged
 from gajim.common.client import Client
 from gajim.common.const import AvatarSize
 from gajim.common.const import SimpleClientState
 from gajim.common.const import StyleAttr
-from gajim.common.i18n import _
+from gajim.common.ged import EventHelper
 from gajim.common.helpers import allow_showing_notification
 from gajim.common.helpers import play_sound
-from gajim.common.ged import EventHelper
+from gajim.common.i18n import _
 
 from .builder import get_builder
+from .structs import AccountJidParam
+from .structs import OpenEventActionParams
 from .util import add_css_to_widget
 from .util import get_monitor_scale_factor
 from .util import get_total_screen_geometry
-from .structs import AccountJidParam
-from .structs import OpenEventActionParams
 
 log = logging.getLogger('gajim.gui.notification')
 
@@ -187,7 +188,11 @@ class PopupNotification(Gtk.Window):
             icon_name = self._get_icon_name(event)
             self._ui.image.set_from_icon_name(icon_name, Gtk.IconSize.DIALOG)
         self._ui.event_type_label.set_text(event.title)
-        self._ui.event_description_label.set_text(event.text)
+        body = textwrap.fill(event.text,
+                             width=40,
+                             max_lines=3,
+                             placeholder='…')
+        self._ui.event_description_label.set_text(body)
 
         if timeout > 0:
             self._timeout_id = GLib.timeout_add_seconds(timeout, self.destroy)
@@ -294,7 +299,7 @@ class Linux(NotificationBackend):
                            res: Gio.AsyncResult) -> None:
             try:
                 proxy = Gio.DBusProxy.new_finish(res)
-                self._caps = proxy.GetCapabilities()  # type: ignore
+                self._caps = proxy.GetCapabilities()  # pyright: ignore
             except GLib.Error as error:
                 log.warning('Notifications D-Bus not available: %s', error)
             else:
@@ -408,8 +413,12 @@ def _get_avatar_for_notification(account: str,
     size = AvatarSize.NOTIFICATION
     client = app.get_client(account)
     contact = client.get_module('Contacts').get_contact(jid)
-    avatar_surface = contact.get_avatar(size, scale)
-    pixbuf = Gdk.pixbuf_get_from_surface(avatar_surface, 0, 0, size, size)
+    surface = contact.get_avatar(size, scale)
+    pixbuf = Gdk.pixbuf_get_from_surface(surface,
+                                         0,
+                                         0,
+                                         size * scale,
+                                         size * scale)
     assert pixbuf is not None
     return pixbuf
 
