@@ -25,43 +25,42 @@ import logging
 import math
 import sys
 import textwrap
-from io import BytesIO
-from importlib import import_module
-from functools import wraps
 from functools import lru_cache
+from functools import wraps
+from importlib import import_module
+from io import BytesIO
 from pathlib import Path
 from re import Match
 
-from PIL import Image
+import cairo
 from gi.repository import Gdk
+from gi.repository import GdkPixbuf
 from gi.repository import Gio
+from gi.repository import GLib
 from gi.repository import Gtk
 from gi.repository import GtkSource
-from gi.repository import GLib
 from gi.repository import Pango
-from gi.repository import GdkPixbuf
-import cairo
-import nbxmpp
 from nbxmpp import JID
+from nbxmpp import util as nbxmpp_util
 from nbxmpp.structs import LocationData
 from nbxmpp.structs import TuneData
+from PIL import Image
 
 from gajim.common import app
 from gajim.common import configpaths
 from gajim.common import types
-from gajim.common.i18n import _
-from gajim.common.helpers import URL_REGEX
-from gajim.common.const import LOCATION_DATA
 from gajim.common.const import Display
+from gajim.common.const import LOCATION_DATA
 from gajim.common.const import StyleAttr
 from gajim.common.ged import EventHelper as CommonEventHelper
+from gajim.common.helpers import URL_REGEX
+from gajim.common.i18n import _
 from gajim.common.modules.contacts import GroupchatParticipant
-from gajim.common.styling import PlainBlock
 from gajim.common.structs import VariantMixin
+from gajim.common.styling import PlainBlock
 
 from .const import WINDOW_MODULES
 
-
 log = logging.getLogger('gajim.gui.util')
 
 
@@ -406,11 +405,10 @@ def format_tune(data: TuneData) -> str:
     title = GLib.markup_escape_text(data.title or _('Unknown Title'))
     source = GLib.markup_escape_text(data.source or _('Unknown Source'))
 
-    tune_string = _('<b>"%(title)s"</b> by <i>%(artist)s</i>\n'
-                    'from <i>%(source)s</i>') % {'title': title,
-                                                 'artist': artist,
-                                                 'source': source}
-    return tune_string
+    return _('<b>"%(title)s"</b> by <i>%(artist)s</i>\n'
+             'from <i>%(source)s</i>') % {'title': title,
+                                          'artist': artist,
+                                          'source': source}
 
 
 def get_account_tune_icon_name(account: str) -> Optional[str]:
@@ -504,10 +502,10 @@ class MaxWidthComboBoxText(Gtk.ComboBoxText):
 
 def text_to_color(text: str) -> tuple[float, float, float]:
     if app.css_config.prefer_dark:
-        background = (0, 0, 0)  # RGB (0, 0, 0) black
+        lightness = 60
     else:
-        background = (1, 1, 1)  # RGB (255, 255, 255) white
-    return nbxmpp.util.text_to_color(text, background)  # type: ignore
+        lightness = 40
+    return nbxmpp_util.text_to_color(text, 100, lightness)
 
 
 def get_contact_color(contact: types.ChatContactT
@@ -567,7 +565,7 @@ def get_pixbuf_from_data(file_data: bytes) -> Optional[GdkPixbuf.Pixbuf]:
                     'convert avatar image using pillow')
         try:
             avatar = Image.open(BytesIO(file_data)).convert('RGBA')
-            array = GLib.Bytes.new(avatar.tobytes())  # type: ignore
+            array = GLib.Bytes.new(avatar.tobytes())  # pyright: ignore
             width, height = avatar.size
             pixbuf = GdkPixbuf.Pixbuf.new_from_bytes(
                 array, GdkPixbuf.Colorspace.RGB,
@@ -627,7 +625,7 @@ def load_pixbuf(path: Union[str, Path],
             log.debug('Error', exc_info=True)
             return None
 
-        array = GLib.Bytes.new(avatar.tobytes())  # type: ignore
+        array = GLib.Bytes.new(avatar.tobytes())  # pyright: ignore
         width, height = avatar.size
         pixbuf = GdkPixbuf.Pixbuf.new_from_bytes(
             array, GdkPixbuf.Colorspace.RGB, True,
@@ -682,7 +680,7 @@ def get_app_windows(account: str) -> list[Gtk.Window]:
     windows: list[Gtk.Window] = []
     for win in app.app.get_windows():
         if hasattr(win, 'account'):
-            if win.account == account:  # type: ignore
+            if win.account == account:  # pyright: ignore
                 windows.append(win)
     return windows
 
@@ -696,11 +694,11 @@ def get_app_window(name: str,
             continue
 
         if account is not None:
-            if account != win.account:  # type: ignore
+            if account != win.account:  # pyright: ignore
                 continue
 
         if jid is not None:
-            if jid != win.jid:  # type: ignore
+            if jid != win.jid:  # pyright: ignore
                 continue
         return win
     return None
@@ -720,17 +718,16 @@ def open_window(name: str, **kwargs: Any) -> Any:
 
 
 def get_gtk_version() -> str:
-    gtk_ver = '%i.%i.%i' % (
+    return '%i.%i.%i' % (
         Gtk.get_major_version(),
         Gtk.get_minor_version(),
         Gtk.get_micro_version())
-    return gtk_ver
 
 
 class EventHelper(CommonEventHelper):
     def __init__(self):
         CommonEventHelper.__init__(self)
-        self.connect('destroy', self.__on_destroy)  # type: ignore
+        self.connect('destroy', self.__on_destroy)  # pyright: ignore
 
     def __on_destroy(self, *args: Any) -> None:
         self.unregister_events()
@@ -895,12 +892,15 @@ def make_menu_item(label: str,
                    action: Optional[str] = None,
                    value: MenuValueT = None) -> Gio.MenuItem:
 
+    item = Gio.MenuItem.new(label)
+
     if value is None:
-        return Gio.MenuItem.new(label, action)
+        item.set_action_and_target_value(action, None)
+        return item
 
     item = Gio.MenuItem.new(label)
     if isinstance(value, str):
-        item.set_detailed_action(f'{action}({value})')
+        item.set_action_and_target_value(action, GLib.Variant('s', value))
     elif isinstance(value, VariantMixin):
         item.set_action_and_target_value(action, value.to_variant())
     else:
