@@ -19,37 +19,35 @@ import datetime
 
 from gi.repository import Gdk
 from gi.repository import GLib
-from gi.repository import Gtk
 from gi.repository import GObject
-
+from gi.repository import Gtk
 from nbxmpp.modules.vcard4 import VCard
 
-from gajim.common.i18n import _
-from gajim.common.i18n import Q_
 from gajim.common.const import URIType
 from gajim.common.helpers import open_uri
 from gajim.common.helpers import parse_uri
+from gajim.common.i18n import _
+from gajim.common.i18n import p_
 from gajim.common.structs import URI
-from gajim.common.text_helpers import escape_iri_path_segment
+from gajim.common.util.text import escape_iri_path_segment
 from gajim.gui.util import gtk_month
 from gajim.gui.util import python_month
 
-
 LABEL_DICT = {
     'fn': _('Full Name'),
     'n': _('Name'),
     'bday': _('Birthday'),
     'gender': _('Gender'),
-    'adr': Q_('?profile:Address'),
+    'adr': p_('Profile', 'Address'),
     'tel': _('Phone No.'),
     'email': _('Email'),
-    'impp': _('IM Address'),
-    'title': Q_('?profile:Title'),
-    'role': Q_('?profile:Role'),
-    'org': _('Organisation'),
-    'note': Q_('?profile:Note'),
+    'impp': p_('Profile', 'IM Address'),
+    'title': p_('Profile', 'Title'),
+    'role': p_('Profile', 'Role'),
+    'org': p_('Profile', 'Organisation'),
+    'note': p_('Profile', 'Note'),
     'url': _('URL'),
-    'key': Q_('?profile:Public Encryption Key'),
+    'key': p_('Profile', 'Public Encryption Key'),
 }
 
 
@@ -118,8 +116,8 @@ ORDER = [
 SEX_VALUES = {
     'M': _('Male'),
     'F': _('Female'),
-    'O': Q_('?Gender:Other'),
-    'N': Q_('?Gender:None'),
+    'O': p_('Gender', 'Other'),
+    'N': p_('Gender', 'None'),
     'U': _('Unknown')
 }
 
