@@ -15,16 +15,13 @@
 from __future__ import annotations
 
 from typing import Any
-from typing import List
-from typing import Optional
 from typing import cast
+from typing import Optional
 
 import logging
 import pickle
 
 from gi.repository import Gdk
-from gi.repository import Gio
-from gi.repository import GLib
 from gi.repository import Gtk
 from nbxmpp.protocol import JID
 
@@ -34,7 +31,9 @@ from gajim.common.i18n import _
 
 from .chat_list_stack import ChatListStack
 from .chat_page import ChatPage
+from .menus import get_workspace_menu
 from .structs import ChatListEntryParam
+from .util import GajimPopover
 from .util import open_window
 
 log = logging.getLogger('gajim.gui.workspace_sidebar')
@@ -122,8 +121,9 @@ class WorkspaceSideBar(Gtk.ListBox):
         if item_type == 'WORKSPACE_SIDEBAR_ITEM':
             self._process_workspace_drop(data.decode('utf-8'))
         elif item_type == 'CHAT_LIST_ITEM':
-            account, jid = pickle.loads(data)
-            self._process_chat_list_drop(account, jid, y_coord)
+            account, jid, source_workspace = pickle.loads(data)
+            self._process_chat_list_drop(
+                account, jid, source_workspace, y_coord)
         else:
             log.debug('Unknown item type dropped')
 
@@ -151,15 +151,17 @@ class WorkspaceSideBar(Gtk.ListBox):
     def _process_chat_list_drop(self,
                                 account: str,
                                 jid: JID,
+                                source_workspace: str,
                                 y_coord: int) -> None:
 
         workspace_row = cast(Workspace, self.get_row_at_y(y_coord))
-        if workspace_row.workspace_id == 'add':
-            app.window.move_chat_to_new_workspace(
-                account, jid)
-            return
 
-        params = ChatListEntryParam(workspace_id=workspace_row.workspace_id,
+        workspace_id = workspace_row.workspace_id
+        if workspace_row.workspace_id == 'add':
+            workspace_id = ''
+
+        params = ChatListEntryParam(workspace_id=workspace_id,
+                                    source_workspace_id=source_workspace,
                                     account=account,
                                     jid=jid)
         app.window.activate_action('move-chat-to-workspace',
@@ -218,18 +220,23 @@ class WorkspaceSideBar(Gtk.ListBox):
         self.insert(row, len(self.get_children()) - 1)
 
     def store_workspace_order(self) -> None:
-        workspaces: list[CommonWorkspace] = cast(
-            list[CommonWorkspace], self.get_children())
-        order: list[str] = [row.workspace_id for row in workspaces]
+        workspaces = cast(list[CommonWorkspace], self.get_children())
+        order = [row.workspace_id for row in workspaces]
         order.remove('add')
         app.settings.set_app_setting('workspace_order', order)
 
-    def remove_workspace(self, workspace_id: str) -> bool:
-        if len(self._workspaces) == 1:
-            return False
+    def remove_workspace(self, workspace_id: str) -> None:
         row = self._workspaces.pop(workspace_id)
         self.remove(row)
-        return True
+
+    def get_other_workspace(self,
+                            exclude_workspace_id: str
+                            ) -> Optional[str]:
+
+        for workspace in self._workspaces.values():
+            if workspace.workspace_id != exclude_workspace_id:
+                return workspace.workspace_id
+        return None
 
     def activate_workspace(self, workspace_id: str) -> None:
         row = cast(CommonWorkspace, self.get_selected_row())
@@ -239,6 +246,11 @@ class WorkspaceSideBar(Gtk.ListBox):
         row = self._workspaces[workspace_id]
         self.select_row(row)
 
+    def activate_workspace_number(self, number: int) -> None:
+        row = cast(CommonWorkspace, self.get_row_at_index(number))
+        if row is not None and row.workspace_id != 'add':
+            app.window.activate_workspace(row.workspace_id)
+
     def get_active_workspace(self) -> Optional[str]:
         row = cast(CommonWorkspace, self.get_selected_row())
         if row is None:
@@ -246,8 +258,7 @@ class WorkspaceSideBar(Gtk.ListBox):
         return row.workspace_id
 
     def get_first_workspace(self) -> str:
-        workspaces: list[CommonWorkspace] = cast(
-            list[CommonWorkspace], self.get_children())
+        workspaces = cast(list[CommonWorkspace], self.get_children())
         for row in workspaces:
             return row.workspace_id
         return ''
@@ -255,8 +266,7 @@ class WorkspaceSideBar(Gtk.ListBox):
     def get_workspace_by_id(self,
                             workspace_id: str
                             ) -> Optional[CommonWorkspace]:
-        workspaces: list[CommonWorkspace] = cast(
-            list[CommonWorkspace], self.get_children())
+        workspaces = cast(list[CommonWorkspace], self.get_children())
         for row in workspaces:
             if row.workspace_id == workspace_id:
                 return row
@@ -311,6 +321,7 @@ class Workspace(CommonWorkspace):
             entries,
             Gdk.DragAction.MOVE)
         eventbox.connect('drag-begin', self._on_drag_begin)
+        eventbox.connect('drag-end', self._on_drag_end)
         eventbox.connect('drag-data-get', self._on_drag_data_get)
         eventbox.connect('button-press-event', self._popup_menu)
         eventbox.add(overlay)
@@ -321,33 +332,12 @@ class Workspace(CommonWorkspace):
         if event.button != 3:  # right click
             return
 
-        menu = self._get_workspace_menu()
+        menu = get_workspace_menu(
+            self.workspace_id, self._unread_label.get_visible())
 
-        rectangle = Gdk.Rectangle()
-        rectangle.x = int(event.x)
-        rectangle.y = int(event.y)
-        rectangle.width = rectangle.height = 1
-
-        popover = Gtk.Popover.new_from_model(self, menu)
-        popover.set_relative_to(self)
-        popover.set_position(Gtk.PositionType.RIGHT)
-        popover.set_pointing_to(rectangle)
+        popover = GajimPopover(menu, relative_to=self, event=event)
         popover.popup()
 
-    def _get_workspace_menu(self) -> Gio.Menu:
-        menu_items: List[Any] = [
-            ('edit-workspace', _('Edit…')),
-        ]
-        menu = Gio.Menu()
-        for item in menu_items:
-            action, label = item
-            action = f'win.{action}'
-            menuitem = Gio.MenuItem.new(label, action)
-            variant = GLib.Variant('s', self.workspace_id)
-            menuitem.set_action_and_target_value(action, variant)
-            menu.append_item(menuitem)
-        return menu
-
     def update_avatar(self) -> None:
         self._image.update()
 
@@ -359,9 +349,10 @@ class Workspace(CommonWorkspace):
         self._unread_label.set_visible(bool(count))
 
     def _on_drag_begin(self,
-                       _widget: Gtk.Widget,
+                       row: Workspace,
                        drag_context: Gdk.DragContext
                        ) -> None:
+
         scale = self.get_scale_factor()
         surface = app.app.avatar_storage.get_workspace_surface(
             self.workspace_id, AvatarSize.WORKSPACE, scale)
@@ -371,6 +362,15 @@ class Workspace(CommonWorkspace):
         listbox = cast(WorkspaceSideBar, self.get_parent())
         listbox.set_drag_row(self)
 
+        app.window.highlight_dnd_targets(row, True)
+
+    def _on_drag_end(self,
+                     row: Workspace,
+                     drag_context: Gdk.DragContext
+                     ) -> None:
+
+        app.window.highlight_dnd_targets(row, False)
+
     def _on_drag_data_get(self,
                           _widget: Gtk.Widget,
                           _drag_context: Gdk.DragContext,
@@ -404,6 +404,7 @@ class WorkspaceAvatar(Gtk.Image):
     def __init__(self, workspace_id: str) -> None:
         Gtk.Image.__init__(self)
         self._workspace_id = workspace_id
+        self.get_style_context().add_class('workspace-avatar')
         self.update()
 
     def update(self) -> None:
